import axios from 'axios'
import qs from 'qs'
import { Toast } from 'vant'
import router from '@/router'

const httpRequest = axios.create({
  baseURL: process.env.VUE_APP_BASE_API,
  timeout: 60000,
  headers: { 'Content-Type': 'application/x-www-form-urlencoded' }
})

// 请求拦截
httpRequest.interceptors.request.use(
  function(config) {
    if (
      config.headers['Content-Type'] === 'application/x-www-form-urlencoded'
    ) {
      config.data = qs.stringify(config.data)
    }
    return config
  },
  function(error) {
    return Promise.reject(error)
  }
)

// 响应拦截
httpRequest.interceptors.response.use(
  function(response) {
    return response.data
  },
  function(error) {
    if (error.response) {
      const { status } = error.response.data
      if (status === 403) {
        router.replace({
          path: '/login',
          query: { redirect_uri: encodeURIComponent(window.location.href) }
        })
      }
    } else {
      Toast({ type: 'error', message: error })
    }
    return Promise.reject(error)
  }
)

export default httpRequest
